@@ -14,4 +14,17 @@
 
 import pkg_resources
 
-__version__ = pkg_resources.get_distribution("splunk-opentelemetry").version
+pkg = pkg_resources.get_distribution("splunk-opentelemetry")
+
+__version__ = pkg.version
+
+
+def format_version_info():
+    lines = []
+    lines.append("splunk-opentelemetry=={0}".format(pkg.version))
+    lines.append("\n\nAlso uses the following OpenTelemetry libraries:\n")
+    for dep in pkg.requires():
+        if "opentelemetry" in dep.name:
+            lines.append("\t{0}".format(str(dep)))
+
+    return "\n".join(lines)
